[![Build Status](https://travis-ci.org/Acellera/htmd.svg?branch=master)](https://travis-ci.org/Acellera/htmd)
[![Language Grade: Python](https://img.shields.io/lgtm/grade/python/g/Acellera/htmd.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Acellera/htmd/context:python) 
[![Conda](https://anaconda.org/acellera/htmd/badges/version.svg)](https://anaconda.org/acellera/HTMD)
<!---[![Build status](https://ci.appveyor.com/api/projects/status/m1bxrop34b2qw68x/branch/master?svg=true)](https://ci.appveyor.com/project/acelleraci/htmd/branch/master)--->


# HTMD: Programming Environment for Molecular Discovery
[HTMD](https://www.htmd.org) (acronym for High-Throughput Molecular Dynamics) is a programmable, extensible platform 
written in Python. It provides a complete workspace for simulation-based discovery through molecular simulations while 
aiming to solve the data generation and analysis problem as well as increase reproducibility.

## Licensing
HTMD Community Edition is free to use for non-profit work. Contact Acellera 
[www.acellera.com/contact](https://www.acellera.com/contact/) for information on the full version HTMD Pro or if you need a different license.

## Download HTMD

### Using released versions
HTMD is distributed through conda package manager. The instructions for downloading HTMD can be found in
[https://software.acellera.com/download.html](https://software.acellera.com/download.html). 

### Using this repository 
If you want to use this repository, we recommend to still download a released version of HTMD to have all dependencies 
and then set PYTHONPATH to the git directory.

## HTMD Documentation and User Guide
For HTMD Documentation, please visit: 
[https://software.acellera.com/docs/latest/htmd/api.html](https://software.acellera.com/docs/latest/htmd/api.html).

For a User Guide (easy to start examples), please visit: 
[https://software.acellera.com/docs/latest/htmd/tutorials.html](https://software.acellera.com/docs/latest/htmd/tutorials.html)

## Support and Development

Please report bugs via [GitHub Issues](https://github.org/acellera/htmd/issues).

HTMD is an open-source software and we welcome contributions from the community. For more information on how to 
contribute to HTMD, please visit:
[https://software.acellera.com/docs/latest/htmd/developers/howto.html](https://software.acellera.com/docs/latest/htmd/developers/howto.html)

## Citing HTMD

If you use HTMD in your publication please cite:

Stefan Doerr, Matthew J. Harvey, Frank Noé, and Gianni De Fabritiis. 
**HTMD: High-throughput molecular dynamics for molecular discovery.** 
*Journal of Chemical Theory and Computation*, **2016**, *12* (4), pp 1845–1852.
[doi:10.1021/acs.jctc.6b00049](http://pubs.acs.org/doi/abs/10.1021/acs.jctc.6b00049)


